<toc>
    <div class="fw-bold text-uppercase mb-2">On this page</div>
    {{ if eq .Site.Params.docs.scrollSpy true -}}
        {{ .TableOfContents | replaceRE "<nav id=\"TableOfContents\">" "<nav id=\"toc\">" | safeHTML }}
    {{ else -}}
        {{ .TableOfContents }}
    {{ end -}}
</toc>