<link rel="preload" as="font" href="{{ "/docs/fonts/nunito-v25-latin-300.woff2" | absURL }}" type="font/woff2" crossorigin>
    <link rel="preload" as="font" href="{{ "/docs/fonts/nunito-v25-latin-regular.woff2" | absURL }}" type="font/woff2" crossorigin>
    <link rel="preload" as="font" href="{{ "/docs/fonts/nunito-v25-latin-500.woff2" | absURL }}" type="font/woff2" crossorigin>
    <link rel="preload" as="font" href="{{ "/docs/fonts/nunito-v25-latin-600.woff2" | absURL }}" type="font/woff2" crossorigin>
    <link rel="preload" as="font" href="{{ "/docs/fonts/nunito-v25-latin-700.woff2" | absURL }}" type="font/woff2" crossorigin>
    <link rel="preload" as="font" href="{{ "/docs/fonts/source-code-pro-v22-latin-500.woff2" | absURL }}" type="font/woff2" crossorigin>
    <link rel="preload" as="font" href="{{ "/docs/fonts/source-code-pro-v22-latin-700.woff2" | absURL }}" type="font/woff2" crossorigin>
    <!-- <link rel="preload" as="font" href="{{ "/docs/fonts/material-symbols-outlined.woff2" | absURL }}" type="font/woff2" crossorigin> -->