<script defer data-domain="{{ .Site.Params.plausible.dataDomain }}" {{ if .Site.Params.plausible.eventAPI }}data-api="{{ .Site.Params.plausible.eventAPI | default }}"{{ end }} src='{{ .Site.Params.plausible.scriptURL | default "plausible.io" }}'></script>