<!-- https://github.com/rvanhorn/hugo-dynamic-tabs -->
{{ $tabName := .Get "tabName" }}
{{ $tabID := delimit (shuffle (slice "a" "b" "c" "d" "e" "f")) "" }}
{{ .Parent.Scratch.Add "tabName" (slice $tabName) }}
{{ .Parent.Scratch.Add "tabID" (slice $tabID) }}

<div class="tab-pane fade{{ if eq .Ordinal 0 }} show active{{ end }}" id="{{ $tabID }}" role="tabpanel" aria-labelledby="nav-1">

	{{ $.Inner }}

</div>