{{ define "main"}}    
      <div class="d-flex flex-column justify-content-center align-items-center four-oh-four">                    
        <div class="px-1">
            <h1 class="text-center">Page not found :(</h1>
            <h4 class="text-center">The page you are looking for doesn't exist or has been moved.</h4>
        </div>
        <div class="px-1">            
            <a href="{{ "" | relURL }}"><i class="material-icons size-48 me-0">home</i></a>
            <!-- <a href="{{ "" | relURL }}"><i class="material-icons size-48 me-0">menu_book</i></a> -->
        </div>
      </div>    
{{ end }}