//
// _badge.scss
//

//Badges
.badge {
    letter-spacing: 1.1px;
    padding: 6px 8px 7px 8px;
    font-weight: 600;
    line-height: 11px;
    border-radius: 4px;
    &.badge-link {
        &:hover {
            color: var(--white) !important;
        }
    }
}