// Google Material Icon Font via
// https://github.com/marella/material-symbols/tree/main/material-symbols

@font-face {
    font-family: 'Material Symbols Outlined';
    font-weight: 400 700;
    font-display: block;
    font-style: normal;
    src: local('Material Symbols Outlined'), local('Material Icons'), local('MaterialIcons-Outlined'),
      url('../fonts/material-symbols-outlined.woff2') format('woff2'), /* Super Modern Browsers */
      // url('../fonts/material-symbols-outlined.woff') format('woff'); /* Modern Browsers */
  }