// magenta
:root {
    --primary: var(--magenta);
    --primary-50: var(--magenta-50);
    --primary-100: var(--magenta-100);
    --primary-200: var(--magenta-200);
    --primary-300: var(--magenta-300);
    --primary-400: var(--magenta-400);
    --primary-800: var(--magenta-800);

    --primary-hsl: var(--magenta-500-hsl);
    --primary-50-hsl: var(--magenta-50-hsl);
    --primary-100-hsl: var(--magenta-100-hsl);
    --primary-200-hsl: var(--magenta-200-hsl);
    --primary-300-hsl: var(--magenta-300-hsl);
    --primary-800-hsl: var(--magenta-800-hsl);
}