//
// dropdown.scss
//

:root {
    --dropdown-link-color: var(--text-default);
    --dropdown-bg: var(--body-bg);
    --dropdown-border-color: var(--alert-border-color);
    --dropdown-border-radius: 0 0 4px 4px;

    --dropdown-link-hover-color: var(--primary);
}

[data-dark-mode] {
    --dropdown-link-color: var(--text-default);
    --dropdown-bg: var(--body-bg);
    --dropdown-border-color: var(--alert-border-color);
    --dropdown-border-radius: 0 0 4px 4px;

    --dropdown-link-hover-color: var(--primary-300);
}

.dropdown-menu {
    --bs-dropdown-min-width: 7rem;
    --#{$prefix}dropdown-link-color: var(--dropdown-link-color);
    --#{$prefix}dropdown-bg: var(--dropdown-bg);
    --#{$prefix}dropdown-border-color: var(--dropdown-border-color);

    --#{$prefix}dropdown-link-hover-bg: none;
    --#{$prefix}dropdown-link-hover-color: var(--dropdown-link-hover-color);

    --#{$prefix}dropdown-border-radius: var(--dropdown-border-radius);

    transform: translate(0px, 57px) !important;
    border-top: none;
}